@@ -12,8 +12,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from typing import Any, Callable, Dict, IO, Mapping, Optional, Union
-from urllib.parse import ParseResult, urlparse
+import os
+from typing import Any, Dict, Optional
+from urllib.parse import urlparse
 
 try:
     import mlflow
@@ -23,15 +24,13 @@ except ImportError:
         "`pip install mlflow` explicitly or install "
         "the correct extras like `pip install rikai[mlflow]`"
     )
-from mlflow.exceptions import MlflowException
 from mlflow.tracking import MlflowClient
-from pyspark.sql import SparkSession
 
 from rikai.logging import logger
-from rikai.spark.sql.codegen.base import codegen_from_spec, ModelSpec, Registry
+from rikai.spark.sql.codegen.base import ModelSpec, Registry, udf_from_spec
 from rikai.spark.sql.codegen.mlflow_logger import (
-    CONF_MLFLOW_ARTIFACT_PATH,
     CONF_MLFLOW_MODEL_FLAVOR,
+    CONF_MLFLOW_MODEL_TYPE,
     CONF_MLFLOW_OUTPUT_SCHEMA,
     CONF_MLFLOW_POST_PROCESSING,
     CONF_MLFLOW_PRE_PROCESSING,
@@ -83,7 +82,12 @@ class MlflowModelSpec(ModelSpec):
         old_uri = mlflow.get_tracking_uri()
         try:
             mlflow.set_tracking_uri(self.tracking_uri)
-            return getattr(mlflow, self.flavor).load_model(self.model_uri)
+            if self.flavor == "tensorflow":
+                return mlflow.pyfunc.load_model(
+                    self.model_uri
+                )._model_impl.model
+            else:
+                return getattr(mlflow, self.flavor).load_model(self.model_uri)
         finally:
             mlflow.set_tracking_uri(old_uri)
 
@@ -108,10 +112,11 @@ class MlflowModelSpec(ModelSpec):
                 CONF_MLFLOW_SPEC_VERSION,
                 MlflowLogger._CURRENT_MODEL_SPEC_VERSION,
             ),
-            "schema": _get_model_prop(conf, CONF_MLFLOW_OUTPUT_SCHEMA),
+            "schema": conf.get(CONF_MLFLOW_OUTPUT_SCHEMA, None),
             "model": {
                 "flavor": _get_model_prop(conf, CONF_MLFLOW_MODEL_FLAVOR),
                 "uri": uri,
+                "type": conf.get(CONF_MLFLOW_MODEL_TYPE, None),
             },
             "transforms": {
                 "pre": conf.get(CONF_MLFLOW_PRE_PROCESSING, None),
@@ -119,11 +124,15 @@ class MlflowModelSpec(ModelSpec):
             },
         }
 
-        # remove none value of pre/post processing
+        # remove none value
         if not spec["transforms"]["pre"]:
             del spec["transforms"]["pre"]
         if not spec["transforms"]["post"]:
             del spec["transforms"]["post"]
+        if not spec["model"]["type"]:
+            del spec["model"]["type"]
+        if not spec["schema"]:
+            del spec["schema"]
 
         # options
         for key, value in conf.items():
@@ -167,9 +176,7 @@ def _get_model_prop(
 class MlflowRegistry(Registry):
     """MLFlow-based Model Registry"""
 
-    def __init__(self, spark: SparkSession):
-        self._spark = spark
-        self._jvm = spark.sparkContext._jvm
+    def __init__(self):
         self._mlflow_client = None
 
     def __repr__(self):
@@ -187,13 +194,10 @@ class MlflowRegistry(Registry):
 
     @property
     def mlflow_tracking_uri(self):
-        return self._spark.conf.get(CONF_MLFLOW_TRACKING_URI)
+        return os.environ.get(CONF_MLFLOW_TRACKING_URI)
 
-    def resolve(self, raw_spec):
-        name = raw_spec.getName()
-        uri = raw_spec.getUri()
-        logger.info(f"Resolving model {name} from {uri}")
-        logger.info(f"Using tracking uri: {self.mlflow_tracking_uri}")
+    def make_model_spec(self, raw_spec):
+        uri = raw_spec["uri"]
         parsed = urlparse(uri)
         if parsed.netloc:
             raise ValueError(
@@ -210,21 +214,17 @@ class MlflowRegistry(Registry):
             self.mlflow_tracking_uri,
             options=self.get_options(raw_spec, run),
         )
-        func_name = codegen_from_spec(self._spark, spec, name)
-        model = self._jvm.ai.eto.rikai.sql.model.SparkUDFModel(
-            name, uri, func_name, raw_spec.getFlavor()
-        )
-        return model
+        return spec
 
     def get_model_conf(self, spec, run):
         """
         Get the configurations needed to specify the model
         """
         from_spec = [
-            (CONF_MLFLOW_MODEL_FLAVOR, spec.getFlavor()),
-            (CONF_MLFLOW_PRE_PROCESSING, spec.getPreprocessor()),
-            (CONF_MLFLOW_POST_PROCESSING, spec.getPostprocessor()),
-            (CONF_MLFLOW_OUTPUT_SCHEMA, spec.getSchema()),
+            (CONF_MLFLOW_MODEL_FLAVOR, spec["flavor"]),
+            (CONF_MLFLOW_PRE_PROCESSING, spec.get("preprocessor", None)),
+            (CONF_MLFLOW_POST_PROCESSING, spec.get("postprocessor", None)),
+            (CONF_MLFLOW_OUTPUT_SCHEMA, spec["schema"]),
         ]
         tags = {k: v for k, v in from_spec if v}
         # PEP 448 syntax, right-to-left priority order
@@ -232,7 +232,8 @@ class MlflowRegistry(Registry):
 
     def get_options(self, spec, run):
         options = run.data.params
-        options.update(spec.getOptions() or {})
+        if spec.get("options", {}):
+            options.update(spec.get("options"))
         return options
 
     def get_model_version(
